#
# spec file for package haruna
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           haruna
Version:        0.10.3
Release:        bp155.1.6
Summary:        Video player built with Qt/QML on top of libmpv
License:        CC-BY-4.0 AND GPL-3.0-or-later AND WTFPL
URL:            https://invent.kde.org/multimedia/haruna
Source0:        https://download.kde.org/stable/haruna/%{name}-%{version}.tar.xz
BuildRequires:  cmake >= 3.15
BuildRequires:  extra-cmake-modules >= 5.66
BuildRequires:  hicolor-icon-theme
BuildRequires:  libQt5Gui-private-headers-devel
BuildRequires:  pkgconfig
BuildRequires:  cmake(Breeze)
BuildRequires:  cmake(KF5Config)
BuildRequires:  cmake(KF5ConfigWidgets)
BuildRequires:  cmake(KF5CoreAddons)
# not actually optional
BuildRequires:  cmake(KF5DocTools)
BuildRequires:  cmake(KF5FileMetaData)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5IconThemes)
BuildRequires:  cmake(KF5KIO)
BuildRequires:  cmake(KF5Kirigami2)
BuildRequires:  cmake(KF5XmlGui)
BuildRequires:  cmake(Qt5Core) >= 5.15.2
BuildRequires:  cmake(Qt5DBus) >= 5.15.2
BuildRequires:  cmake(Qt5Gui) >= 5.15.2
BuildRequires:  cmake(Qt5Qml)
BuildRequires:  cmake(Qt5Quick)
BuildRequires:  cmake(Qt5QuickControls2)
BuildRequires:  cmake(Qt5X11Extras)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavdevice)
BuildRequires:  pkgconfig(libavfilter)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libpostproc)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(mpv)
Requires:       breeze5-icons
%if 0%{?sle_version} != 150300
Requires:       yt-dlp
%else
Requires:       youtube-dl
%endif

%description
%{name} is a video player built with Qt/QML on top of libmpv.

%lang_package

%prep
%autosetup -p1

%build
%cmake
%cmake_build

%install
%cmake_install

%find_lang %{name}

# let's remove the documentation for now
rm -rf %{buildroot}%{_datadir}/doc

# remove oddly-sized icons
rm -rf %{buildroot}%{_datadir}/icons/hicolor/44x44 \
       %{buildroot}%{_datadir}/icons/hicolor/150x150 \
       %{buildroot}%{_datadir}/icons/hicolor/310x310

%files
%license LICENSES/CC-BY-4.0.txt LICENSES/GPL-3.0-or-later.txt
%doc README.md
%{_bindir}/%{name}
%{_datadir}/applications/org.kde.haruna.desktop
%{_datadir}/icons/hicolor/*/apps/haruna.*g
%{_datadir}/metainfo/org.kde.haruna.metainfo.xml

%files lang -f %{name}.lang

%changelog
* Sun Jan 29 2023 Dirk Müller <dmueller@suse.com>
- update to 0.10.3:
  * mpvitem: use loadFile() method on PlayListModel::playingItemChanged() signal
  * only link the KIO libs that are actualy used
  * Fix relative M3U loading
  * HProgressBar: refactor chapters menu into a popup with a listview
  * HProgressBar: add tooltip for 'Skip Chapter' checkbox in chapters popup
  * playlistmodel: getSiblingItems: use percent-encoded path with QUrl
* Wed Jan 25 2023 Dominique Leuenberger <dimstar@opensuse.org>
- No need to BuildRequire yt-dlp/youtube-dl: this is only a
  runtime dependency.
* Sat Jan  7 2023 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.10.2
  Bugfixes:
  * Fixed crash when "Maximum recent files" setting was set to
    zero.
* Fri Jan  6 2023 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.10.1
  Bugfixes:
  * Fixed not auto playing next file in playlist, when current
    file ends
  * Fixed opened file not playing when "Auto load videos from
    same folder" setting is disabled
* Tue Jan  3 2023 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.10.0
  Features:
  * Playlist: added options to open m3u files (without support
    for extended attributes), add files and urls (only the url
    path will be displayed, no title and no duration), sort,
    clear and save the playlist
  * Playlist: added context menu for the playlist items
  * Playlist: added setting to remember playlist state
  * Subtitles: added setting to render subtitle in black borders
  * Video: added setting to set a default cover for music files
  * Added command line option to override the ytdl format
    selection setting (this option is overwritten if the GUI
    setting is changed)
  * Added MPRIS thumbnail
  Bugfixes:
  * Recent files: fixed ordering, showing duplicates, clearing
    and adding when list is full
  * Fixed OSD showing without text
  * Playlist: fixed "Increase font size when fullscreen" setting
    not working
  * Playlist: removed rowHeight setting
* Wed Oct 12 2022 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.9.3
  * playlistmodel: set QUrl scheme if not set
  * actionsmodel: port QRegExp to QRegularExpression
  * only use Qt5X11Extras with qt5
  * cmake: add support for qt6
  * pass correct type to QMetaObject::invokeMethod
  * change emit to Q_EMIT
  * use a QUrl instead of a QString where a QUrl is expected
  * switch to Q_SIGNALS and Q_SLOTS
- Added lang subpackage
* Fri Oct  7 2022 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.9.2
  * actionsmodel: change text of togglePlaylistAction action to
    just Playlist
  * recentfilesmodel: use custom implementation instead of
    KRecentFilesAction
  * window: use Kirigami gridUnit for width and height
  * mpv: move mpris connections to cpp
  * Settings: improve right to left behaviour
  * footer: fix play next/previous button icons in right to left
    mode
  * footer: fix seek bar and volume bar right to left behaviour
  * playlistmodel: use a QUrl to determine the mimetype
  * mpv: fix includes and call methods from MpvCore instead of
    MpvItem
  * Footer: improve font scaling
  * SubtitlesFolders: fix model name
  * settings: use qmlRegisterSingletonInstance instead of
    qmlRegisterSingletonType
  * Add a menu item in the Subtitles header button and menubar
    to open a subtitle file
  * CustomCommands: use `Kirigami.PlaceholderMessage` when there
    are no commands
  * Remove explicit use of ECM_KDE_MODULE_DIR, is part of
    ECM_MODULE_PATH
  * mpvitem: remove duplicated property
* Wed Aug 24 2022 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.9.1
  Bugfixes:
  * Fixed two broken actions in the global menu
  * Fixed translations
* Mon Aug 22 2022 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.9.0
  Features:
  * Refactored the shortcuts configuration, now it's available
    in the settings window with the other settings, instead of
    opening another window
  * Hamburger menu now only show a few actions, the rest are
    available in a submenu
  * When menubar is hidden the hamburger menu will be shown in
    the header/toolbar and when the header is hidden it's shown
    in the footer
  * Added a proper context menu for the video
  * Added setting to start playback when resuming playback of a
    file
  * Added setting to set maximum number of recent files
  * Added option to clear recent files
  * Added setting to restore window size and position
  * Added settings to customize the subtitle font family, size,
    style (bold, italic), color, shadow color, shadow offset,
    border color, border width
  * Moved seek settings to playback settings page
  * Moved volume step setting to audio settings page
  * Custom commands that run on startup can be turned off so
    they are not set on next run
  * In mouse settings the action text, which is translatable, is
    shown instead of it's internal name
  Bugfixes:
  * Toggling menubar and header/toolbar through actions
    remembers the state on next run
  * Restore time position for youtube videos
  * Improve mpv initialization to allow better hardware decoding
    support
  * Ytdl-format property can be overwritten by a custom command
    action
- Switch to yt-dlp where available
* Wed Apr 20 2022 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.8.0
  * fix: wrong height for playlist items
  * Fix freezes on systems with slow disks
  * Fix build warnings and errors
  * fix: mark methods as override
  * chore: remove unused code
  * fix: load correct files and call functions from actions
    manager
  * fix: release date for 0.7.3
  * fix: don't run animation when component is hidden
  * SVN_SILENT made messages (.desktop file) - always resolve
    ours
  * GIT_SILENT made messages (after extraction)
  * fix: menubar not hiding in fullscreen
  * refactor: improvements to framedecoder
  * feat: add global menu support
  * fix: compile with MPV_CLIENT_API_VERSION 1 and 2
  * feat: add action to seek to watch later position
    (Ctrl+Shift+P)
  * feat: add action to restart playback (seek to 0/beginning,
    F5 key)
  * feat: add action to load last played file (Ctrl+Shift+L)
  * chore: add .directory to gitignore
  * fix: rename icons license files
  * fix(osd): when file can't be played show filename if there's
    no title
  * build: use ECMAddAppIcon module
  * feat: allow to control the time position saving interval
  * refactor: add Settings to settings qml file names
  * refactor: rename SettingsEditor to SettingsWindow
  * refactor: put settings window in a loader
  * build: add KDECMakeSettings and KDECompilerSettings
  * fix: get actions from actionsManager
  * chore: add license info to actionsmanager.cpp/h
  * refactor: move actions cpp code to its own class
  * fix: remove unused cursor hiding/showing code
  * fix(playlist): use position from PlaylistSettings
  * fix(playlist): set height to mpv height
  * fix(playlist): unable to close the playlist
  * feat(menu): add more actions
  * build: add header files to target_sources
  * chore: remove more unneeded code
  * chore: remove unneeded code
  * chore: remove id from repeater
  * feat: add menu to open recent files
  * build: add FindYtdlp.cmake file
  * Add i18n()
  * SVN_SILENT made messages (.desktop file) - always resolve
    ours
  * GIT_SILENT made messages (after extraction)
  * feat: Add setting to pause the player if minimized
  * fix(settigs): clarify remember time position settings
  * chore(settings): remove labels from .kcfg files
  * fix(settings): load subtitles folders correctly
- Drop haruna-mpv_v2_fix.patch (merged upstream)
* Sun Jan 30 2022 Luigi Baldoni <aloisio@gmx.com>
- Add haruna-mpv_v2_fix.patch (fixes Factory build)
* Wed Nov  3 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.7.3
  * fix(settings): load icon in settings page
  * fix: lower tooltip font size
  * fix: rename icon in desktop file
  * fix: install only one icon
  * fix(header): fix toolbutton menu not closing
  * feat(mpv): keep file loaded after eof is reached
  * Revert "fix: keep file loaded after reaching end of file"
  * feat(playlistmodel): add appendVideo method
  * fix(settings): raise window when clicking configure button
  * fix: keep file loaded after reaching end of file
  * fix(settings): load correct file for the General page
  * fix: report bug button in about page not working
  * fix(youtube-dl): prioritize yt-dlp
  * fix(icon): install haruna.svg icon
  * fix(mpris): only show filename if there's no title
  * refactor(Settings): add about page and move navigation code
    in settings editor
  * Extract messages for configuration keys
  * refactor(Settings): move actions inside list view
  * fix(Settings): make sidebar elements translatable
* Sun Sep 26 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.7.2
  * fix(PlayListItem): set correct height
  * GIT_SILENT made messages (after extraction)
  * fix: make mouse action filtering case insensitive
  * fix: change how cursor is hidden in fullscreen
  * Delete FUNDING.yml
  * Update README.md
  * Settings: dont open window at startup
* Mon Sep 13 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.7.1
  * Settings window: decrease width
  * Settings: use Kirigami gridUnit for width and height
  * Settings: remove page before pushing another one
  * Fix video repeating when repeat is turned off
  * Remove quit button from toolbar
  * Fix play/pause button being disabled when it shouldn't
  * Change resume playback setting into 2 settings
  * PlayListItem: remove id
  * PlayList: remove ids from playlist items
  * Install icon in the correct path
- Drop haruna-icon_path.patch and haruna-playlist_noid.patch
  (merged upstream)
* Mon Aug 23 2021 Luigi Baldoni <aloisio@gmx.com>
- Add haruna-icon_path.patch and haruna-playlist_noid.patch
  (backported fixes)
* Fri Aug 20 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.7.0 (see changelog at
  https://invent.kde.org/multimedia/haruna/-/compare/0.6.3...v0.7.0
* Wed Apr 28 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.6.3
  * Set breeze icon theme before QApplication creation
* Sat Apr 17 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.6.2
  * MpvObject: set youtube-dl format before loading file
  * Bundle ssl certs from certify
* Wed Apr  7 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.6.1
  * Update desktop file
  * add link to flathub page
  * MpvObject
  * Playlist model
* Wed Mar 31 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.6.0
  * Remove color schemes until their license is clear
  * MPVObject: show loading indicator for all videos
  * Disable next/previous buttons when there's 1 or no video in
    the playlist
  * Add youtube-dl to dependencies list
  * Don't use breeze icons by default
  * GUI style
  * Add copyrights
  * Correct copyright and license for cmake/FindLibmpv.cmake
  * MenuBar
  * Add checks before trying to access data
  * MpvObject
  * PlaylistModel: avoid index out of range error
  * Audio/Subtitles settings
  * Always open first video in new youtube playlist
  * Remove wrong license files
  * Add license to files without one
  * Skip videos that can't be played
  * Add loading indicator for youtube videos
  * If youtube-dl is not available display a message instead of
    the controls to open a url
  * PlayListItemWithThumbnail change elide mode to
    WrapAtWordBoundaryOrAnywhere
  * Add dependencies and build instructions to readme file
  * Youtube playlist
  * PlaylistItem
  * Worker::getMetaData return if there's no extractor available
  * CMake
  * Make mpris player dbus interface a qml context property
  * Add mpris2 support
  * Fix play next/prev actions not updating the LastPlayedFile
  * Use LabelWithTooltip without prefix
  * Add placeholder and tooltip for 'Skip chapters' feature Add
    help for 'Remember time position' and 'Skip chapters' features
  * Refactor time position saving
  * Rename custom label component to LabelWithTooltip
  * MpvObject: fix cursor not hiding in fullscreen
  * MpvObject: resume playback changes
  * Settings: don't togggle hw decoding with save file position
    checkbox
  * Update README.md
  * Add FUNDING.yml
  * Settings: change default screenshots folder
  * MpvObject: add resume/restart video popup
  * Settings: add option to disable file position saving and
    resuming
  * MpvObject: update tracks models when mpv's track-list changes
  * Remove console.log
  * MpvObject: allow loading subtitles through drag and drop
  * MpvObject: allow to print the error in get/setProperty
    methods
  * MpvObject: move loadFile function to the cpp side
  * Application: make getFileContent parameter const
  * MpvObject
  * MpvObject
  * main.qml: fix mpv.scrollPositionTimer ->
    playList.scrollPositionTimer
  * Generate AppImage from every build (#43)
  * Settings
  * Update help for old Breeze style option to fit the changes
  * Settings: remove notice about Breeze not being installed
  * SettingsBasePage: replace i18n with qsTr
  * MpvObject: fix next file not loading when current file
    finishes
  * Playback Settings
  * Remove wrong and unused id
  * Use add command to change volume and speed properties Set
    max volume to 100
  * CMake: make set_package_properties more compact
  * Seetings navigation: Set padding for each side, fix for Qt
    5.12
  * Register PlayListModel type for qml usage
  * CMake: add FindLibmpv.cmake file
  * Add liberapay and paypal donation links
  * Refactor file loading code
  * application.h: reorder some functions, remove some unused
    code
  * Refactor youtube playlist code
  * MpvObject: comment code in getYouTubePlaylist
  * Thumbnail image provider: provide generic icon for urls
  * MpvObject: extract youtube playlist code to function
  * Refactor to allow opening youtube playlists through "Open
    Url"
  * Show osd message when toggling deinterlacing
  * Header: use only one RowLayout
  * Playlist: remove style property, use PlaylistSettings.style
  * Header: remove buttons to toggle playlist Footer: use
    loaders for the playlist toggle button
  * data/appdata.xml: Make validation successful
  * Add import path for qml components
  * Actions: rename "Toggle Playlist" to "Playlist"
  * MpvVideo: consider the playlist position when anchoring
  * Header, Footer: add another button to toggle the playlist,
    one on the left and one on the right coresponding to the
    playlist's position
  * Playlist: add compact style
  * Playlist: fix playlist items coloring
  * Playlist: add option to push video instead of overlaying it
  * Add button in the header and footer to toggle the playlist
    when toggling it with the mouse is disabled
  * MpvVideo: settings are in a window so ancoring to it is wrong
  * Settings: refactor mouse page
  * Settings: add custom component for images adjustments sliders
  * Setings: remove color adjustments page
  * SettingsHeader: add top margin
  * Settings: make casing consistent
  * Settings: remove unneeded properties
  * Refactor settings window
  * Make configure header button uncheckable Don't close
    settings window (if open) when going fullscreen
  * Add action to toggle video deinterlacing
  * Open settings in separate window
  * qthelper.h: fix build with Qt 5.12
- Drop haruna-0.5.0-Qt512_fix.patch (merged upstream)
* Wed Jan 20 2021 aloisio@gmx.com
- Add haruna-0.5.0-Qt512_fix.patch
* Mon Jan 11 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.5.0
  * Update about data
  * Playback settings: remove unnecesary layout
  * Refactor settings pages
  * Add SettingsHeader component
  * Settings: add option to toggle hardware decoding
  * MpvObject: move code from eventHandler to connections
  * Replace mpv_set_option_string with setProperty
  * mpvopbject.cpp: use const container in tracks loop, clazy
    range-loop
  * qthelper: remove deprecated functions
  * Emit signals when tracks change
  * Refactor audio and subtitle tracks model into properties
  * Remove unused code
  * Add emit before dataChanged signal
  * Settings: fix open config file and folder not working
  * Settings: add help page for general settings
  * Settings: check if the Breeze style is available,
  * Settings: split useBreezeTheme in two settings,
  * Save SkipChapters setting when changed from progress bar menu
  * Add option to set file dialog location
  * CMake: look for breeze, kirigami and qt5qml
  * Fix breeze icon theme name
  * Add option to use the breeze icon theme and GUI style
  * Link against KIconThemes
  * Fix video not playing when opened from playlist
  * CMake: remove REQUIRED from find_package
  * Use the new label component where appropriate
  * Add custom label component
* Wed Dec  9 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.4.2
  * Mouse Settings: use ListModel instead of array
  * Fix mouse actions
- Drop haruna-0.4.1-fix_mouse_actions.patch (merged upstream)
* Tue Dec  8 2020 aloisio@gmx.com
- Add haruna-0.4.1-fix_mouse_actions.patch
* Tue Dec  8 2020 aloisio@gmx.com
- Update to version 0.4.1
  * Fix build on Qt 5.12
  * Save last played file
  version 0.4.0:
  * Change back to qmlRegisterSingletonType
  * add some mimetypes and KDE file handlers (from mpv)
  * Use KConfig to handle settings
  * Fix crash when using the playPrevious action
  * Settings: fix ComboBox delegate width
  * Change back to Flickable for the help window
  * CMake: fix file paths
  * Add license files for color scheme files
  * CMake: fix target_include_directories paths
  * CMake: add option to install color schemes
  * CMake: use target_include_directories and update includes
  * Rename Settings folder to settings
  * CMake: use target_sources
  * Playlist: highlight playing video
  * Add option to switch between simple playlist items
  * Add PlayListItemWithThumbnail component
  * Add image provider for video thumbnails
- Drop haruna-0.3.1-fix_crash_wih_Qt512.patch
  and haruna-0.3.1-fix_version.patch (merged upstream)
* Fri Dec  4 2020 aloisio@gmx.com
- Add haruna-0.3.1-fix_crash_wih_Qt512.patch and
  haruna-0.3.1-fix_version.patch
* Tue Dec  1 2020 aloisio@gmx.com
- Update to version 0.3.1
  * Playlist: always hide horizontal scrollbar
  * Add include for QPointer in application.cpp
  * Fix includes in application.cpp
- Drop haruna-0.3.0-QPointer.patch (merged upstream)
* Tue Dec  1 2020 aloisio@gmx.com
- Update to version 0.3.0
  * Playlist: hide horizontal scrollbar
  * Cleanup Application constructor
  * Move code from main.cpp to application.cpp
  * Move qml type registration, thread, about data and
  * MPV: refactor loading file code
  * MPV: make pause property writable
  * Use ScrollView and TextArea for help pages
  * Pass all metadata from worker to playlist model
  * ProgressBar: Disable middle click when chapter markers are
    hidden
  * Add option to hide chapter markers
  * Fix menu and header toggle actions breaking binding of
    'visible' prop…
  * Add help menu with about haruna action
  * Add about action
  * Use KAboutData setters for more clarity
  * Remove feature_summary from src/CMakeLists.txt
  * Upper case fusion style name
  * Use mpv.command to load file from playlist
  * Add setting to disable adding videos from same folder to
    playlist
  * Add clear method to playlist model
  * Add playlistitem constructor and set its properties inside it
  * Play next action jumps to first video if current video is
  * Add setting to repeat playlist or stop after last video
    finished
  * Add watchPercentage property to mpv,
- Add haruna-0.3.0-QPointer.patch
* Mon Nov  2 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.2.2
  * Fixed incompatibilities with Qt 5.12
- Drop haruna-desktop.patch, haruna-qt512_1.patch and
  haruna-qt512_2.patch
* Wed Oct 14 2020 Luigi Baldoni <aloisio@gmx.com>
- Initial package (v0.2.1)
